==> fourseasons-5.x-0.3.tar.gz: fourseasons/admin/toggle-style.tpl.php <==
<script type="text/javascript" src="/theme/misc/jquery.js"></script>
<script type="text/javascript" src="/theme/misc/drupal.js"></script>
<script type="text/javascript" src="/theme/misc/collapse.js"></script>

<script type="text/javascript">

function toggle_style(color) {
  $('#header-image').css('background-color', color);
  $('h1').css('color', color);
  $('h2').css('color', color);
  $('h3').css('color', color);
  $('#headline a').css('color', color);
}

</script>

<style type="text/css">
    #font span,
    #farben span {
      font-family:arial; 
      color:#333333; 
      font-size:10px; 
      text-decoration:none; 
      float:left; 
      display:block;
    }
    
    #farben a {
      width:10px; 
      height:10px; 
      display:block;
      float:left;
      margin-left:5px;
    }
  
    #font a {
      display:block;
      float:left;
      margin-left:5px;
      font-family:arial;
      color:#cccccc;
      font-size:10px;
      text-decoration:none;
    }
  </style>

  <div id="farben">
    <span>try another color: </span>
    <a href="#" style="background-color:#FF9900;" onClick="toggle_style('#FF9900');"></a>
    <a href="#" style="background-color:#003366;" onClick="toggle_style('#003366');"></a>
    <a href="#" style="background-color:#990000;" onClick="toggle_style('#990000');"></a>
    <a href="#" style="background-color:#CCCCCC;" onClick="toggle_style('#CCCCCC');"></a>
    <a href="#" style="background-color:#006699;" onClick="toggle_style('#006699');"></a>
    <a href="#" style="background-color:#000000;" onClick="toggle_style('#000000');"></a>
  </div>

  <div id="font">
    <span style="margin-left:20px;">try another fontsize: </span>
    <a href="#" onClick="$('body').css('font-size','60%');">60%</a>
    <a href="#" onClick="$('body').css('font-size','70%');">70%</a>
    <a href="#" onClick="$('body').css('font-size','80%');">80%</a>
    <a href="#" onClick="$('body').css('font-size','90%');">90%</a>
  </div>

==> fourseasons-5.x-0.15.tar.gz: fourseasons/admin/toggle-style.tpl.php <==
<script type="text/javascript" src="/theme/misc/jquery.js"></script>
<script type="text/javascript" src="/theme/misc/drupal.js"></script>
<script type="text/javascript" src="/theme/misc/collapse.js"></script>

<script type="text/javascript">

function toggle_style(color) {
  $('#header-image').css({'background-image' : 'none', 'background-color': color});
  $('h1').css('color', color);
  $('h2').css('color', color);
  $('h3').css('color', color);
  $('#headline a').css('color', color);
}

</script>

<style type="text/css">
    #font span,
    #farben span {
      font-family:arial; 
      color:#333333; 
      font-size:10px; 
      text-decoration:none; 
      float:left; 
      display:block;
    }
    
    #farben a {
      width:10px; 
      height:10px; 
      display:block;
      float:left;
      margin-left:5px;
    }
  
    #font a {
      display:block;
      float:left;
      margin-left:5px;
      font-family:arial;
      color:#cccccc;
      font-size:10px;
      text-decoration:none;
    }
  </style>

  <div id="farben">
    <span>try another color: </span>
    <a href="#" style="background-color:#FF9900;" onClick="toggle_style('#FF9900');"></a>
    <a href="#" style="background-color:#003366;" onClick="toggle_style('#003366');"></a>
    <a href="#" style="background-color:#990000;" onClick="toggle_style('#990000');"></a>
    <a href="#" style="background-color:#CCCCCC;" onClick="toggle_style('#CCCCCC');"></a>
    <a href="#" style="background-color:#006699;" onClick="toggle_style('#006699');"></a>
    <a href="#" style="background-color:#000000;" onClick="toggle_style('#000000');"></a>
  </div>

  <div id="font">
    <span style="margin-left:20px;">try another fontsize: </span>
    <a href="#" onClick="$('body').css('font-size','60%');">60%</a>
    <a href="#" onClick="$('body').css('font-size','70%');">70%</a>
    <a href="#" onClick="$('body').css('font-size','80%');">80%</a>
    <a href="#" onClick="$('body').css('font-size','90%');">90%</a>
  </div>
